# FeverIQ

FeverIQ provides an API and SDK for using **Secure Multiparty Computation (SMC)** to estimate the transmission- and complication- risks relating to the SARS-CoV-2 coronavirus. Secure Multiparty Computation allows third parties to compute on sensitive data, without the unprotected data ever leaving the phone or browser. Depending on how you set things up, for example, only the data source (e.g. the patient who provided their symptoms) can see the results of the computation.

# Usage

The FeverIQ API and SDK is provided as an `npm package` for easy incorporation with existing websites and react apps. The core functionality can be incorporated with only a few lines of code.

```js
import feveriq from 'feveriq';

const input = {
  demographic: {
    "Age":    Integer,
    "Bmi":    Integer, /*MKS units - kg/m2 - rounded to Int*/
    "Gender": "Female" || "Male" || "Other",
    "TemperatureC": Float /*Celsius - you are responsible for converting from Fahrenheit if needed*/
    "Travel_Self": false || true, /*Have YOU traveled out of state lately?*/
    "Travel_CloseContact": false || true, /*Have you had close contact with someone else who has traveled out of state lately?*/
  },
  symptoms: {
    "Fever":                false || true,
    "Unexplained Fatigue":  false || true,
    "Dry Cough":            false || true,
    "Sneezing":             false || true,
    "Aches":                false || true,
    "Runny Nose":           false || true,
    "Sore Throat":          false || true,
    "Diarrhea":             false || true,
    "Headache":             false || true,
    "Trouble Breathing":    false || true,
    "Loss of smell":        false || true,
    "Unexplained Allergies":false || true,
    "Hallucinations":       false || true,
    "Vomiting":             false || true,
    "Blue Toes":            false || true,
    "Skipped Meals":        false || true,
    "COVID-19 in household":false || true ,
    "COVID-19 test result": null || false || true,
    "COVID-19 test type":   "PCR" || "IMMUNO",
  },
  comorbidities: {
    "Asthma":                 false || true,
    "Cancer":                 false || true,
    "Chronic Kidney Disease": false || true,
    "COPD":                   false || true,
    "Cystic Fibrosis":        false || true,
    "Diabetes":               false || true,
    "Heart Disease":          false || true,
    "Hepatitis":              false || true,
    "High Blood Pressure":    false || true,
    "HIV":                    false || true,
    "Liver Cirrhosis":        false || true,
    "Organ Transplant":       false || true,
    "SCID":                   false || true,
    "Sickle Cell":            false || true,
    "Smoking/Vaping":         false || true,
  }
}
```

# Using the API

```js
const api_key = "YOUR_API_KEY"; // Obtained from https://healthcheck.feveriq.com/settings

feveriq.api_key(api_key);
feveriq.input(input);
feveriq.Main().then(res => console.log(res));
```

**Note:** Our system will automatically set missing symptoms or values to `false`.

# Example of standard output

```js
{
  personalScore: 3.5,        /*risk to self if infected*/
  personalRisk: 'Normal',    /*risk to self if infected {Normal, Elevated, High}*/
  testScore: 0.129,          /*main SARS scoring algo - if > CP1_ct1, elevated likelihood of testing positive if tested*/
  transmissionRisk: 'Normal',/*{Normal, Elevated, High}*/
  recommendToTest: false,    /*Should you get tested?*/
  quarantineScore: 0,        /*quarantine length suggestion*/
  quarantineDuration: 0,     /*days of suggested quarantine*/
  timesStamp: 1593546575820, /*unix time when estimates were generated*/
  integrityHash: 'fa5f6c9ffa5f6c9ffa5f6c9f', /*used for regulatory compliance*/
  uniqueComputeID: '74213c74-39c6-4c36-bbdd-15216f24ac96', /*unique identifier of computation*/
  status: 201,
}
```

# Demo

The FeverIQ site demonstrates some of the core features of the SDK. Please visit the [**Health Check**](https://healthcheck.feveriq.com) site to learn more.

# Support

For more information and support, please contact [**contact@feveriq.com**](mailto:contact@feveriq.com).

## V1.1.1 (November 10, 2020)

* v1.1.1 release (November 10, 2020)

Updated the quarantine duration

* v1.0.24 release (September 25, 2020)

Fixed bug

* v1.0.23 release (August 3, 2020)

Updated models

* v1.0.22 release (July 29, 2020)

Added travel questions

* v1.0.21 release (July 28, 2020)

Fixed bugs

* v1.0.17 release (July 27, 2020)

Code refactoring, better variable names, improved documentation

* v1.0.13 release (July 21, 2020)

Remove Blood Type A and Blood Type B risk factor for complications

* v1.0.12 release (July 14, 2020)

Add smoking/vaping risk factor for complications

* v1.0.11 release (July 10, 2020)

Improve documentation, restructure code

* v1.0.0 release

First public release